@@ -40,7 +40,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.01;
+    our $VERSION = 1.02;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -418,8 +418,8 @@ sub new {
         'DEBUGMAX_LastStamp' => time,                                 # Initialize the DEBUGMAX benchmark
         'LOG'                => $LOG,                                 # Pull in the global Log::Fast object.
         'Color'              => TRUE,                                 # Default to colorized output
-        'DateStamp'          => colored(['yellow on_black'], '%d'),
-        'TimeStamp'          => colored(['yellow on_black'], '%t'),
+        'DateStamp'          => colored(['yellow on_black'], '%date%'),
+        'TimeStamp'          => colored(['yellow on_black'], '%time%'),
         'Padding'            => -15,                                  # Default padding is 15 spaces
         'CPadding'           => -2,
         'Prefix'             => '%Date% %Time% %Benchmark% %Loglevel%[%Subroutine%][%Lastline%] ',
